==> gmssl-sdf-crypto-1.0.0-20191119.103842-1-sources.jar: com/xdja/pki/gmssl/crypto/sdf/SdfSHADigest.java <==
package com.xdja.pki.gmssl.crypto.sdf;

import com.xdja.pki.gmssl.sdf.SdfSDK;
import com.xdja.pki.gmssl.sdf.SdfSDKException;
import com.xdja.pki.gmssl.sdf.bean.SdfAlgIdHash;
import com.xdja.pki.gmssl.sdf.bean.SdfRSAPublicKey;
import com.xdja.pki.gmssl.sdf.yunhsm.YunhsmSdfSDK;
import org.bouncycastle.crypto.ExtendedDigest;
import org.bouncycastle.util.Memoable;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 *
 */
public class SdfSHADigest extends SdfBaseDigest {
    private static final int SHA1_DIGEST_LENGTH = 20;   // bytes
    private static final int SHA256_DIGEST_LENGTH = 32;   // bytes
    private static final int BYTE_LENGTH = 64;   // bytes

    private SdfAlgIdHash sdfAlgIdHash;

    public SdfSHADigest(SdfAlgIdHash sdfAlgIdHash) throws SdfSDKException {
        this(SdfCryptoType.YUNHSM, sdfAlgIdHash);

    }

    public SdfSHADigest(SdfCryptoType sdfCryptoType, SdfAlgIdHash sdfAlgIdHash) throws SdfSDKException {
        this(sdfCryptoType.getSdfSDK(), sdfAlgIdHash);

    }

    public SdfSHADigest(SdfSDK sdfSDK, SdfAlgIdHash sdfAlgIdHash) throws SdfSDKException {
        this.sdfSDK = sdfSDK;
        this.sdfSDK.init();
        this.sdfAlgIdHash = sdfAlgIdHash;
//        this.init();
    }


    public SdfSHADigest(SdfSHADigest t) throws SdfSDKException {
        copyIn(t);
    }

    private void init() throws SdfSDKException {
        sdfSDK.hashInit(this.sdfAlgIdHash);
        this.isInit = true;
    }


    @Override
    protected void checkInit() throws SdfSDKException {
        if (!this.isInit) {
            //hash init
            this.init();
        }
    }

    private void copyIn(SdfSHADigest t) throws SdfSDKException {
        //sdf sdk copy
        this.sdfSDK = SdfCryptoType.cloneSdfSDK(t.sdfSDK);
        this.sdfSDK.init();
        this.checkInit();
        if (t.in != null) {
            this.update(t.in, 0, t.in.length);
        }
    }

    @Override
    public String getAlgorithmName() {
        return this.sdfAlgIdHash.getName();
    }

    @Override
    public int getDigestSize() {
        return sdfAlgIdHash.getId() == SdfAlgIdHash.SGD_SHA1.getId() ? SHA1_DIGEST_LENGTH : SHA256_DIGEST_LENGTH;
    }

    @Override
    public int getByteLength() {
        return BYTE_LENGTH;
    }

    @Override
    public Memoable copy() {
        try {
            return new SdfSHADigest(this);
        } catch (SdfSDKException e) {
            logger.error("Memoable copy", e);
            return null;
        }
    }

    @Override
    public void reset(Memoable other) {
        SdfSHADigest d = (SdfSHADigest) other;
        try {
            copyIn(d);
        } catch (SdfSDKException e) {
            logger.error("reset copy in error", e);
        }
    }
}

==> gmssl-sdf-crypto-1.1.3-20210703.101241-1-sources.jar: com/xdja/pki/gmssl/crypto/sdf/SdfSHADigest.java <==
package com.xdja.pki.gmssl.crypto.sdf;

import com.xdja.pki.gmssl.sdf.SdfSDK;
import com.xdja.pki.gmssl.sdf.SdfSDKException;
import com.xdja.pki.gmssl.sdf.bean.SdfAlgIdHash;
import com.xdja.pki.gmssl.sdf.bean.SdfECCPublicKey;
import com.xdja.pki.gmssl.sdf.bean.SdfRSAPublicKey;
import com.xdja.pki.gmssl.sdf.yunhsm.YunhsmSdfSDK;
import org.bouncycastle.crypto.ExtendedDigest;
import org.bouncycastle.util.Memoable;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;

public class SdfSHADigest extends SdfBaseDigest {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    private static final int SHA1_DIGEST_LENGTH = 20;
    private static final int SHA256_DIGEST_LENGTH = 32;
    private static final int BYTE_LENGTH = 64;

    private SdfAlgIdHash sdfAlgIdHash;

    public SdfSHADigest(SdfAlgIdHash sdfAlgIdHash) throws SdfSDKException {
        this(SdfCryptoType.YUNHSM, sdfAlgIdHash);

    }

    public SdfSHADigest(SdfCryptoType sdfCryptoType, SdfAlgIdHash sdfAlgIdHash) throws SdfSDKException {
        this(sdfCryptoType.getSdfSDK(), sdfAlgIdHash);
    }

    public SdfSHADigest(SdfSDK sdfSDK, SdfAlgIdHash sdfAlgIdHash) throws SdfSDKException {
        super(sdfSDK);
        this.sdfAlgIdHash = sdfAlgIdHash;
    }

    public SdfSHADigest(SdfSHADigest t) throws SdfSDKException {
        copyIn(t);
    }

    @Override
    protected void init() throws SdfSDKException {
        this.sdfSDK.hashInit(this.sdfAlgIdHash);
    }

    @Override
    public String getAlgorithmName() {
        return this.sdfAlgIdHash.getName();
    }

    @Override
    public int getDigestSize() {
        return sdfAlgIdHash.getId() == SdfAlgIdHash.SGD_SHA1.getId() ? SHA1_DIGEST_LENGTH : SHA256_DIGEST_LENGTH;
    }

    @Override
    public int getByteLength() {
        return BYTE_LENGTH;
    }

    @Override
    public Memoable copy() {
        try {
            return new SdfSHADigest(this);
        } catch (SdfSDKException e) {
            logger.error("Memoable copy", e);
            return null;
        }
    }

    @Override
    public void reset(Memoable other) {
        SdfSHADigest d = (SdfSHADigest) other;
        try {
            copyIn(d);
            d.releaseConnection();
        } catch (SdfSDKException e) {
            logger.error("reset copy in error", e);
        }
    }
}
